#ifndef _CONFIG_H
#define _CONFIG_H

/**************************************************************************
 * PROJECT:	Honda RTP rev. 1.0
 * AUTHOR:	Marcin O'BenY Benka <obeny@obeny.net>
 * VERSION:	1.0 (20091116)
 *
 * DESCRIPTION:	Simple EEPROM (type 27C256) emulator, compatible with
 *		Xtronics ROMulator protocol. This device allows to
 *		perform Real Time Programming of Honda's OBD1 ECU during
 *		tuning process.
 **************************************************************************/

/**************************************************************************
 * NOTE:
 *
 * Hardware configuration definitions.
 **************************************************************************/

/***************************************************************************
 *	INCLUDES
 ***************************************************************************/

#include <avr/version.h>


/***************************************************************************
 *	DEFINITIONS
 ***************************************************************************/

/* CPU frequency */
#define F_CPU 14745600UL

/* IO */
/* address bus */
#define ADDRESS PORTA
#define ADDRESS_DDR DDRA

/* data bus */
#define DATA_DDR DDRC
#define DATA_IN PINC
#define DATA_OUT PORTC
#define DATA_PULLUP PORTC

/* signals mapping */
#define RAMOE PD2		/* pin 11: ROM outputs enable; low active */
#define RAMOE_ACT false
#define RAMOE_PORT PORTD

#define LED_R PD3		/* pin 12: LED1 enable; low active */
#define LED_R_ACT false
#define LED_R_PORT PORTD

#define LED_G PD4		/* pin 13: LED2 enable; low active */
#define LED_G_ACT false
#define LED_G_PORT PORTD

#define ADRHI PD5		/* pin 14: address hi byte latch enable; low - latched */
#define ADRHI_ACT false
#define ADRHI_PORT PORTD

#define ADRLO PD6 		/* pin 15: address lo byte latch enable; low - latched */
#define ADRLO_ACT false
#define ADRLO_PORT PORTD

#define DATDDIR PD7		/* pin 16: data direction; low - read, high - write */
#define DATDDIR_READ false
#define DATDDIR_WRITE true
#define DATDDIR_PORT PORTD

#define RAMWE PB0		/* pin 40: RAM write enable; low active */
#define RAMWE_ACT false
#define RAMWE_PORT PORTB

#define ADRSOE PB1		/* pin 41: ECU socket address outputs enable; low active */
#define ADRSOE_ACT false
#define ADRSOE_PORT PORTB

#define DATDOE PB2		/* pin 42: uC data outputs enable; low active */
#define DATDOE_ACT false
#define DATDOE_PORT PORTB

#define DATSOE PB3		/* pin 43: ECU socket data outputs enable; low active*/
#define DATSOE_ACT false
#define DATSOE_PORT PORTB

#define ADRLOE PB4		/* pin 44: uC address latches output enable; low active */
#define ADRLOE_ACT false
#define ADRLOE_PORT PORTB

/* USART */
#define USART_RBUF_SIZE 64
#define USART_TBUF_SIZE 16
#define USART_SEND_MAX_LENGTH 262
#define USART_USE_STATUS
#define USART_USE_TIMER

/* SYNC TIMER */
#define SYNC_TIMER_COUNT 9
#define SYNC_TIMER_PRESCALER 64
#define SYNC_TIMER_PRESCALER_EDGE
#define SYNC_TIMER_PRESCALER_OCR 255

/* MISC */
#define MEMORY_SIZE 32768
#define MEMORY_WRITE_RETRIES 3

#define FIRMWARE_VERSION FVERSION

#define ROMULATOR_PROTOCOL_ID 0x31
#define ROMULATOR_PROTOCOL_MAJOR 0x01
#define ROMULATOR_PROTOCOL_MINOR 0x28
#define ROMULATOR_PROTOCOL_WRITE_RETRIES 3
#define ROMULATOR_PROTOCOL_READ_TIMEOUT 5


#endif /* _CONFIG_H */
/* END */
